@@ -4,7 +4,7 @@
 #' @param source source to select from.
 #' @param expr expression to select rows.
 #' @param env environment to look for values in.
-#' @return select columns node.
+#' @return select rows node.
 #'
 #' @examples
 #'
@@ -67,12 +67,12 @@ select_rows_se.data.frame <- function(source, expr,
 
 #' Make a select rows node.
 #'
-#' select_rows_nse() uses bquote() .()-style escaping.
+#' select_rows() uses bquote() .()-style escaping.
 #'
 #' @param source source to select from.
 #' @param expr expression to select rows.
 #' @param env environment to look to.
-#' @return select columns node.
+#' @return select rows node.
 #'
 #' @examples
 #'
@@ -81,7 +81,7 @@ select_rows_se.data.frame <- function(source, expr,
 #'   d <- rq_copy_to(my_db, 'd',
 #'                    data.frame(AUC = 0.6, R2 = 0.2, z = 3))
 #'   TARGETCOL = as.name("AUC")
-#'   optree <- select_rows_nse(d, .(TARGETCOL) >= 0.5) %.>%
+#'   optree <- select_rows(d, .(TARGETCOL) >= 0.5) %.>%
 #'     select_columns(., "R2")
 #'   cat(format(optree))
 #'   sql <- to_sql(optree, my_db)
@@ -92,14 +92,19 @@ select_rows_se.data.frame <- function(source, expr,
 #'
 #' @export
 #'
-select_rows_nse <- function(source, expr,
-                            env = parent.frame()) {
+select_rows <- function(source, expr,
+                        env = parent.frame()) {
   force(env)
-  UseMethod("select_rows_nse", source)
+  UseMethod("select_rows", source)
 }
 
+#' @rdname select_rows
 #' @export
-select_rows_nse.relop <- function(source, expr,
+#'
+select_rows_nse <- select_rows
+
+#' @export
+select_rows.relop <- function(source, expr,
                             env = parent.frame()) {
   force(env)
   exprq <- substitute(expr)
@@ -112,7 +117,7 @@ select_rows_nse.relop <- function(source, expr,
     merge_fld(parsed, "symbols_used"),
     merge_fld(parsed, "free_symbols")
   )))
-  check_have_cols(src_columns, required_cols, "rquery::select_rows_nse.relop")
+  check_have_cols(src_columns, required_cols, "rquery::select_rows.relop")
   assignments <- unpack_assignments(source, parsed,
                                     check_is_assignment = FALSE)
   parsed[[1]]$symbols_produced <- character(0)
@@ -126,7 +131,7 @@ select_rows_nse.relop <- function(source, expr,
 }
 
 #' @export
-select_rows_nse.data.frame <- function(source, expr,
+select_rows.data.frame <- function(source, expr,
                             env = parent.frame()) {
   force(env)
   exprq <- substitute(expr)
